@@ -8,6 +8,10 @@
 #include "dkg.h"
 #include "noise_private.h"
 
+#ifdef __ZEPHYR__
+uint64_t ztime(void);
+#endif
+
 /*
     @copyright 2023-24, Stefan Marsiske toprf@ctrlc.hu
     This file is part of liboprf.
@@ -38,7 +42,7 @@
 
 // calculates polynomial f(j) given the polynomials threshold coefficients in
 // array a
-void polynom(const uint8_t j, const uint8_t threshold,
+void __attribute__((visibility("hidden"))) polynom(const uint8_t j, const uint8_t threshold,
                     const uint8_t a[threshold][crypto_core_ristretto255_SCALARBYTES],
                     TOPRF_Share *result) {
   //f(z) = a_0 + a_1*z + a_2*z^2 + a_3*z^3 + ⋯ + (a_t)*(z^t)
@@ -181,30 +185,34 @@ int dkg_finish(const uint8_t n,
   return 0;
 }
 
-void dkg_reconstruct(const size_t response_len,
-                     const TOPRF_Share responses[response_len],
-                     uint8_t result[crypto_scalarmult_ristretto255_BYTES]) {
+void dkg_reconstruct(const size_t threshold,
+                     const TOPRF_Share shares[threshold],
+                     uint8_t secret[crypto_scalarmult_ristretto255_BYTES]) {
   uint8_t lpoly[crypto_scalarmult_ristretto255_SCALARBYTES];
   uint8_t tmp[crypto_scalarmult_ristretto255_SCALARBYTES];
-  memset(result,0,crypto_scalarmult_ristretto255_SCALARBYTES);
+  memset(secret,0,crypto_scalarmult_ristretto255_SCALARBYTES);
 
-  uint8_t indexes[response_len];
-  for(size_t i=0;i<response_len;i++) {
-    indexes[i]=responses[i].index;
+  uint8_t indexes[threshold];
+  for(size_t i=0;i<threshold;i++) {
+    indexes[i]=shares[i].index;
   }
-  for(size_t i=0;i<response_len;i++) {
-    coeff(responses[i].index, response_len, indexes, lpoly);
-    crypto_core_ristretto255_scalar_mul(tmp, responses[i].value, lpoly);
-    crypto_core_ristretto255_scalar_add(result, result, tmp);
+  for(size_t i=0;i<threshold;i++) {
+    coeff(shares[i].index, threshold, indexes, lpoly);
+    crypto_core_ristretto255_scalar_mul(tmp, shares[i].value, lpoly);
+    crypto_core_ristretto255_scalar_add(secret, secret, tmp);
   }
 }
 
 
 //////////////////// utility functions for [s]tp-dkg  ////////////////////
 
-int check_ts(const uint64_t ts_epsilon, uint64_t *last_ts, const uint64_t ts) {
+int __attribute__((visibility("hidden"))) check_ts(const uint64_t ts_epsilon, uint64_t *last_ts, const uint64_t ts) {
   if(*last_ts == 0) {
+#ifdef __ZEPHYR__
+    uint64_t now = ztime();
+#else
     uint64_t now = (uint64_t)time(NULL);
+#endif
     if(ts < now - ts_epsilon) return 3;
     if(ts > now + ts_epsilon) return 4;
   } else {
@@ -215,7 +223,7 @@ int check_ts(const uint64_t ts_epsilon, uint64_t *last_ts, const uint64_t ts) {
   return 0;
 }
 
-int send_msg(uint8_t* msg_buf, const size_t msg_buf_len, const uint8_t type, const uint8_t version, const uint8_t msgno, const uint8_t from, const uint8_t to, const uint8_t *sig_sk, const uint8_t sessionid[dkg_sessionid_SIZE]) {
+int __attribute__((visibility("hidden"))) send_msg(uint8_t* msg_buf, const size_t msg_buf_len, const uint8_t type, const uint8_t version, const uint8_t msgno, const uint8_t from, const uint8_t to, const uint8_t *sig_sk, const uint8_t sessionid[dkg_sessionid_SIZE]) {
   if(msg_buf==NULL) return 1;
   DKG_Message* msg = (DKG_Message*) msg_buf;
   msg->type = type;
@@ -224,14 +232,18 @@ int send_msg(uint8_t* msg_buf, const size_t msg_buf_len, const uint8_t type, con
   msg->msgno = msgno;
   msg->from = from;
   msg->to = to;
+#ifdef __ZEPHYR__
+  msg->ts = htonll((uint64_t) ztime());
+#else
   msg->ts = htonll((uint64_t)time(NULL));
+#endif
   memcpy(msg->sessionid, sessionid, dkg_sessionid_SIZE);
 
   crypto_sign_detached(msg->sig, NULL, &msg->type, sizeof(DKG_Message) - crypto_sign_BYTES, sig_sk);
   return 0;
 }
 
-int recv_msg(const uint8_t *msg_buf, const size_t msg_buf_len, const uint8_t type, const uint8_t version, const uint8_t msgno, const uint8_t from, const uint8_t to, const uint8_t *sig_pk, const uint8_t sessionid[dkg_sessionid_SIZE], const uint64_t ts_epsilon, uint64_t *last_ts ) {
+int __attribute__((visibility("hidden"))) recv_msg(const uint8_t *msg_buf, const size_t msg_buf_len, const uint8_t type, const uint8_t version, const uint8_t msgno, const uint8_t from, const uint8_t to, const uint8_t *sig_pk, const uint8_t sessionid[dkg_sessionid_SIZE], const uint64_t ts_epsilon, uint64_t *last_ts ) {
   if(msg_buf==NULL) return 8;
   const DKG_Message* msg = (const DKG_Message*) msg_buf;
   if(msg->type != type) return 9;
@@ -242,7 +254,7 @@ int recv_msg(const uint8_t *msg_buf, const size_t msg_buf_len, const uint8_t typ
   if(msg->to != to) return 4;
   if(sodium_memcmp(msg->sessionid, sessionid, dkg_sessionid_SIZE)!=0) return 7;
 
-#if !defined(FUZZING_BUILD_MODE_UNSAFE_FOR_PRODUCTION)
+#if !defined(FUZZING_BUILD_MODE_UNSAFE_FOR_PRODUCTION) && !defined(NO_TIME)
   int ret = check_ts(ts_epsilon, last_ts, ntohll(msg->ts));
   if(0!=ret) {
     if(log_file!=NULL) {
@@ -467,7 +479,7 @@ int dkg_noise_decrypt(const uint8_t *input,
 /**
   Return the session unique send key, needed for tp-dkg reveal share.
 */
-uint8_t* Noise_XK_session_get_key(const Noise_XK_session_t *sn) {
+uint8_t __attribute__((visibility("hidden"))) *Noise_XK_session_get_key(const Noise_XK_session_t *sn) {
   Noise_XK_session_t st = sn[0U];
   if (st.tag == Noise_XK_DS_Initiator && st.val.case_DS_Initiator.state.tag == Noise_XK_IMS_Transport)
     return st.val.case_DS_Initiator.state.val.case_IMS_Transport.send_key;
@@ -476,7 +488,7 @@ uint8_t* Noise_XK_session_get_key(const Noise_XK_session_t *sn) {
   return NULL;
 }
 
-void update_transcript(crypto_generichash_state *transcript, const uint8_t *msg, const size_t msg_len) {
+void __attribute__((visibility("hidden"))) update_transcript(crypto_generichash_state *transcript, const uint8_t *msg, const size_t msg_len) {
   uint32_t msg_size_32b = htonl((uint32_t)msg_len);
   crypto_generichash_update(transcript, (uint8_t*) &msg_size_32b, sizeof(msg_size_32b));
   crypto_generichash_update(transcript, msg, msg_len);
