@@ -144,9 +144,9 @@ static void genVDMmatrix(const uint8_t indexes[], const uint8_t index_len,
   }
 }
 
-void invertedVDMmatrix(const uint8_t dealers,
-                       const uint8_t indexes[dealers],
-                       uint8_t inverted[dealers][dealers][crypto_core_ristretto255_SCALARBYTES]) {
+void __attribute__((visibility("hidden"))) invertedVDMmatrix(const uint8_t dealers,
+                                                             const uint8_t indexes[dealers],
+                                                             uint8_t inverted[dealers][dealers][crypto_core_ristretto255_SCALARBYTES]) {
   uint8_t vdm[dealers][dealers][crypto_core_ristretto255_SCALARBYTES];
   genVDMmatrix(indexes, dealers, vdm);
   invert(dealers, vdm, inverted);
@@ -302,6 +302,7 @@ int toprf_mpc_vsps_check(const uint8_t t, const uint8_t A[t*2][crypto_core_ristr
   return 0;
 }
 
+// todo remove dealers param, can be calculatted from t param
 int toprf_mpc_ftmult_step1(const uint8_t dealers, const uint8_t n, const uint8_t t, const uint8_t self,
                            const TOPRF_Share alpha[2], const TOPRF_Share beta[2],
                            const uint8_t lambdas[dealers][crypto_core_ristretto255_SCALARBYTES],
