@@ -3,6 +3,9 @@
 #include "stp-dkg.h"
 #include "dkg-vss.h"
 #include "mpmult.h"
+#ifdef __ZEPHYR__
+#include <zephyr/kernel.h>
+#endif
 
 /*
     @copyright 2025, Stefan Marsiske toprf@ctrlc.hu
@@ -399,7 +402,11 @@ void stp_dkg_stp_set_bufs(STP_DKG_STPState *ctx,
   ctx->commitments = commitments;
   ctx->cheater_max = cheater_max;
   ctx->last_ts = last_ts;
+#ifdef __ZEPHYR__
+  uint64_t now = (uint64_t) k_uptime_get();
+#else
   uint64_t now = (uint64_t)time(NULL);
+#endif
   for(uint8_t i=0;i<ctx->n;i++) ctx->last_ts[i]=now;
 }
 
@@ -592,7 +599,7 @@ static STP_DKG_Err peer_start_noise_handler(STP_DKG_PeerState *ctx, const uint8_
   update_transcript(&ctx->transcript, input, input_len);
 
   // create noise device
-  uint8_t iname[14];
+  uint8_t iname[15];
   snprintf((char*) iname, sizeof iname, "toprf peer %02x", ctx->index);
   uint8_t dummy[32]={0}; // the following function needs a deserialization key, which we never use.
 
